package WebService::Braintree::ErrorCodes::MerchantAccount::ApplicantDetails::Address;
$WebService::Braintree::ErrorCodes::MerchantAccount::ApplicantDetails::Address::VERSION = '0.94';
use 5.010_001;
use strictures 1;

use constant LocalityIsRequired      => "82618";
use constant PostalCodeIsInvalid     => "82630";
use constant PostalCodeIsRequired    => "82619";
use constant RegionIsRequired        => "82620";
use constant StreetAddressIsInvalid  => "82629";
use constant StreetAddressIsRequired => "82617";
use constant RegionIsInvalid         => "82664";

1;
__END__
